$S.val - support for one-way observed versus expected.
$uncorrected.sup - uncorrected support.
$df - degrees of freedom for table.
$observed - observed counts.
$exp.p - expected probabilities.
$too.good - support for the variance of counts being more different than expected.
$chi.sq - chi-squared value.
$p.value - p value for chi-squared.
$LR.test = the likelihood ratio test statistic.
$lrt.p = the p value for the likelihood ratio test statistic
Additional outputs for binomial:
$prob.val - MLE probability from data.
$succ.fail - number of successes and failures.
$like.int - likelihood interval.
$like.int.spec - specified likelihood interval in units of support.
$conf.int - likelihood-based confidence interval.
$alpha.spec - specified alpha for confidence interval.
$err.acc - error accuracy for optimize function.